@@ -509,13 +509,11 @@ double adios_stat_cor_v1 (ADIOS_VARINFO_V1 * vix, ADIOS_VARINFO_V1 * viy, char *
         time_end = min;
     }
     // Check the bounds of time
-    if (    (time_start >= 0) && (time_start <= min)
-            &&      (time_end >= 0)   && (time_end <= min)
-            &&  (time_start <= time_end))
+    if (time_start <= min && time_end <= min && time_start <= time_end)
     {
         if(viy == NULL) //user must want to run covariance against itself
         {
-            if(! (time_end+lag) > min)
+            if(! (time_end+lag > min))
             {                                                                        
                 adios_error(err_invalid_timestep, "Must leave enough timesteps for lag\n");
                 return 0;
@@ -716,13 +714,11 @@ double adios_stat_cov_v1 (ADIOS_VARINFO_V1 * vix, ADIOS_VARINFO_V1 * viy, char *
         time_end = min;
     }
     // Check the bounds of time
-    if (    (time_start >= 0) && (time_start <= min)
-            &&      (time_end >= 0)   && (time_end <= min)
-            &&  (time_start <= time_end))
+    if (time_start <= min && time_end <= min && time_start <= time_end)
     {
         if(viy == NULL) //user must want to run covariance against itself
         {
-            if(! (time_end+lag) > min)
+            if(! (time_end+lag > min))
             {                                                                        
                 adios_error(err_invalid_timestep, "Must leave enough timesteps for lag\n");
                 return 0;
