@@ -54,6 +54,22 @@ module adios_defs_mod
     integer, parameter :: ADIOS_LOCKMODE_CURRENT = 0
     integer, parameter :: ADIOS_LOCKMODE_ALL     = 0
 
+    
+    !
+    ! Selection types
+    !
+    integer, parameter :: ADIOS_SELECTION_TYPE_BOUNDINGBOX  = 0
+    integer, parameter :: ADIOS_SELECTION_TYPE_POINTS       = 1
+    integer, parameter :: ADIOS_SELECTION_TYPE_WRITEBLOCK   = 2
+    integer, parameter :: ADIOS_SELECTION_TYPE_AUTO         = 3
+
+    !
+    ! Statistics option in adios_declare_group()
+    !
+    integer, parameter :: ADIOS_STAT_NO      = -1   ! turn off statistics generation
+    integer, parameter :: ADIOS_STAT_DEFAULT = 0    ! min + max only
+    integer, parameter :: ADIOS_STAT_FULL    = 1    ! all statistics turned on
+
 
     !
     ! ADIOS error codes
