@@ -11,8 +11,7 @@
 #include <stdint.h>
 #include "public/adios_types.h"
 #include "core/adios_internals.h"
-//#include "adios_internals.h"
-
+#include "core/util.h"
 
 int shared_buffer_write(struct adios_file_struct *fd, const void * data, uint64_t size);
 int shared_buffer_reserve(struct adios_file_struct *fd, uint64_t size);
