@@ -12,4 +12,6 @@ REGISTER_TRANSFORM_PLUGIN(isobar, "isobar", "ncsu-isobar", "ISOBAR compression")
 REGISTER_TRANSFORM_PLUGIN(aplod, "aplod", "ncsu-aplod", "APLOD byte-columnar precision-level-of-detail access format")
 REGISTER_TRANSFORM_PLUGIN(alacrity, "alacrity", "ncsu-alacrity", "ALACRITY indexing")
 REGISTER_TRANSFORM_PLUGIN(zfp, "zfp", "zfp", "zfp compression")
-
+REGISTER_TRANSFORM_PLUGIN(sz, "sz", "sz", "sz compression")
+REGISTER_TRANSFORM_PLUGIN(lz4, "lz4", "lz4", "lz4 compression")
+REGISTER_TRANSFORM_PLUGIN(blosc, "blosc", "blosc", "blosc compression")
