@@ -1,6 +1,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <stdlib.h>
+#include <inttypes.h>
 #include <math.h>
 #include <string.h>
 
@@ -21,6 +22,8 @@
 #include "core/util.h"
 #include "core/ds_metadata.h"
 #include "core/adios_logger.h"
+#include "core/globals.h"
+#include "core/buffer.h"
 
 #include "dataspaces.h"
 
@@ -140,7 +143,7 @@ static int connect_to_dspaces (struct adios_ds_data_struct * md, MPI_Comm comm)
         //Init the dart client
         ret = dspaces_init (num_peers, md->appid, &md->mpi_comm_init, NULL);
         if (ret) {
-            log_error ("adios_dataspaces: rank=%d Failed to connect to DATASPACES: err=%d,  rank=%d\n", md->rank, ret);        
+            log_error ("adios_dataspaces: rank=%d Failed to connect to DATASPACES: err=%d\n", md->rank, ret); 
             return ret;
         }
 
@@ -266,22 +269,11 @@ int adios_dataspaces_open (struct adios_file_struct * fd,
     return ret;
 }
 
-enum ADIOS_FLAG adios_dataspaces_should_buffer (struct adios_file_struct * fd
-                                         ,struct adios_method_struct * method
-                                         )
+enum BUFFERING_STRATEGY adios_dataspaces_should_buffer (struct adios_file_struct * fd
+                                                       ,struct adios_method_struct * method
+                                                       )
 {
-    
-    //if (fd->shared_buffer == adios_flag_no && fd->mode != adios_mode_read)
-    //{
-        // write the process group header
-        //adios_write_process_group_header_v1 (fd, fd->write_size_bytes);
-        //adios_write_open_vars_v1 (fd);
-    //} else {
-    //    log_warn("WARNING: %s expects that fd->shared_buffer is false\n", __func__);
-    //}
-    
-
-    return adios_flag_no;  // this will take care of it
+    return no_buffering;  
 }
 
 
@@ -315,6 +307,7 @@ void adios_dataspaces_write (struct adios_file_struct * fd
     int didx[MAX_DS_NDIM]; // for reordering the dimensions
     int ndims = 0;
     int hastime = 0;
+    uint64_t nelems = 1;
     gdims[0] = 0;
     struct adios_dimension_struct* var_dimensions = v->dimensions;
     // Calculate lower and upper bounds for each available dimension (up to MAX_DS_NDIM dims)
@@ -325,7 +318,11 @@ void adios_dataspaces_write (struct adios_file_struct * fd
         lb[ndims] = adios_get_dim_value (&(var_dimensions->local_offset));
         if (gdims[ndims] > 0 && dims[ndims] > 0)  {
             ub[ndims] = lb[ndims] + dims[ndims] - 1;
+            nelems *= dims[ndims];
             ndims++;
+        } else if (gdims[ndims] > 0 && dims[ndims] == 0) {
+            // piece of array with 0 elements, skip it
+            nelems *= dims[ndims];
         }   else {
             // time dimension (ldim=0 indicates this). Leave out from the dimensions.
             //ub[ndims] = lb[ndims]; 
@@ -349,6 +346,11 @@ void adios_dataspaces_write (struct adios_file_struct * fd
 
     //snprintf(dspaces_type_var_name, MAX_DS_NAMELEN, "TYPE@%s", ds_var_name);
     
+    /* The next line is just to fix adios_build_index_v1() call not to abort on 
+     * offset=0 variables (in case of files, written variables have offset > 0)
+     */
+    v->write_offset = 1; 
+
     /* non-global variables are put in space ONLY by rank = 0 process */
     if (gdims[0] == 0 && md->rank != 0) {
         //fprintf(stderr, "rank=%d var_name=%s is not global. Skip\n", md->rank, ds_var_name);
@@ -363,7 +365,6 @@ void adios_dataspaces_write (struct adios_file_struct * fd
     //}
     
      
-    v->write_offset = 1; // only !=0 offsets will be included in build index
     /* This is not needed here, this is already called in common_adios_write() 
     adios_generate_var_characteristics_v1 (fd, v); // characteristics will be included in build index
     adios_write_var_characteristics_v1 (fd, v);
@@ -378,6 +379,13 @@ void adios_dataspaces_write (struct adios_file_struct * fd
             ds_var_name, adios_type_to_string_int(v->type), v->type, var_type_size, version, ndims,
             dims_str, gdims_str, lb_str, ub_str);
 
+
+    /* If variable is empty, do not push to space */
+    if (nelems == 0) {
+        log_debug ("rank=%d var_name=%s is empy variable piece. Skip\n", md->rank, ds_var_name);
+        return;
+    }
+
     /* non-timed scalars are written in the metadata at close(), not here */
     if (ndims == 0 && !hastime)
         return;
@@ -439,7 +447,7 @@ void adios_dataspaces_get_write_buffer (struct adios_file_struct * fd
         if (!*buffer)
         {
             adios_method_buffer_free (mem_allowed);
-            log_error ("ERROR: Out of memory allocating %llu bytes for %s in %s:%s()\n"
+            log_error ("ERROR: Out of memory allocating %" PRIu64 " bytes for %s in %s:%s()\n"
                     ,*size, v->name, __FILE__, __func__
                     );
             v->got_buffer = adios_flag_no;
@@ -460,7 +468,7 @@ void adios_dataspaces_get_write_buffer (struct adios_file_struct * fd
     else
     {
         adios_method_buffer_free (mem_allowed);
-        log_error ("OVERFLOW: Cannot allocate requested buffer of %llu "
+        log_error ("OVERFLOW: Cannot allocate requested buffer of %" PRIu64 
                          "bytes for %s in %s:%s()\n"
                 ,*size
                 ,v->name
@@ -495,7 +503,7 @@ static void adios_dataspaces_gather_indices (struct adios_file_struct * fd
     // build local index first appending to any existing index
     adios_build_index_v1 (fd, index);
 
-    log_debug ("%s index after first build is pg=%x vars=%x attrs=%x\n", 
+    log_debug ("%s index after first build is pg=%p vars=%p attrs=%p\n", 
                 __func__, index->pg_root, index->vars_root, index->attrs_root);
 #if 0
 #if HAVE_MPI
@@ -578,7 +586,7 @@ static void adios_dataspaces_gather_indices (struct adios_file_struct * fd
 #endif
 #endif
 
-    log_debug ("%s index after gathering is pg=%x vars=%x attrs=%x\n", 
+    log_debug ("%s index after gathering is pg=%p vars=%p attrs=%p\n", 
                 __func__, index->pg_root, index->vars_root, index->attrs_root);
 }
 
@@ -713,7 +721,7 @@ void ds_pack_group_info (struct adios_file_struct *fd
         for (i = 0; i<v->characteristics->dims.count; i++) {
             ldims[j] = v->characteristics->dims.dims[j*3];  // ith dimension 
             gdims[j] = v->characteristics->dims.dims[j*3+1];  // ith dimension 
-            log_debug("           , ldim = %lld gdim = %lld)\n", ldims[j], gdims[j]);
+            log_debug("           , ldim = %" PRIu64 " gdim = %" PRIu64 ")\n", ldims[j], gdims[j]);
             if (gdims[j] == 0 && ldims[j] == 1) {
                 // time dimension's global=0, local=1, skip
                 // FIXME: This is true for a local array of length 1 (not defined as global)
@@ -848,6 +856,12 @@ void ds_pack_file_info (int time, int nvars, int nattrs, int group_index_len, ch
     b[namelen] = 0;
 }
 
+void adios_dataspaces_buffer_overflow (struct adios_file_struct * fd, 
+                                       struct adios_method_struct * method)
+{
+    // this call never happens without shared buffering
+}
+
 void adios_dataspaces_close (struct adios_file_struct * fd
                       ,struct adios_method_struct * method
                       )
@@ -1001,7 +1015,7 @@ void adios_dataspaces_finalize (int mype, struct adios_method_struct * method)
             }
         }
 
-        free_dspaces_stream_info(md);
+        free_dspaces_stream_info();
 
         log_info("%s: Disconnect from DATASPACES server now, rank=%d ...\n", __func__, mype);
         // disconnect from dataspaces if we are connected from writer but not anymore from reader
