@@ -163,7 +163,7 @@ static struct adios_dimes_stream_info* lookup_dimes_stream_info(const char* fnam
 static int check_read_status_var(const char* fname, int last_version)
 {
     int stay_in_poll_loop = 1;
-    double t1 = adios_gettime();
+    double t1 = adios_gettime_double();
 
     uint64_t lb[MAX_DS_NDIM], ub[MAX_DS_NDIM], gdims[MAX_DS_NDIM];
     int elemsize, ndim;
@@ -191,7 +191,7 @@ static int check_read_status_var(const char* fname, int last_version)
 
         // check if we need to stay in loop
         if (stay_in_poll_loop) {
-            double elapsed_time = adios_gettime() - t1;
+            double elapsed_time = adios_gettime_double() - t1;
             if (check_read_status_timeout_sec >= 0.0 &&
                 elapsed_time > check_read_status_timeout_sec) {
                 stay_in_poll_loop = 0;
@@ -401,22 +401,11 @@ int adios_dimes_open (struct adios_file_struct * fd,
     return ret;
 }
 
-enum ADIOS_FLAG adios_dimes_should_buffer (struct adios_file_struct * fd
-                                         ,struct adios_method_struct * method
-                                         )
+enum BUFFERING_STRATEGY adios_dimes_should_buffer (struct adios_file_struct * fd
+                                                  ,struct adios_method_struct * method
+                                                  )
 {
-    
-    //if (fd->shared_buffer == adios_flag_no && fd->mode != adios_mode_read)
-    //{
-        // write the process group header
-        //adios_write_process_group_header_v1 (fd, fd->write_size_bytes);
-        //adios_write_open_vars_v1 (fd);
-    //} else {
-    //    log_warn("WARNING: %s expects that fd->shared_buffer is false\n", __func__);
-    //}
-    
-
-    return adios_flag_no;  // this will take care of it
+    return no_buffering;  
 }
 
 
@@ -451,6 +440,7 @@ void adios_dimes_write (struct adios_file_struct * fd
     int didx[MAX_DS_NDIM]; // for reordering the dimensions
     int ndims = 0;
     int hastime = 0;
+    uint64_t nelems = 1;
     gdims[0] = 0;
     struct adios_dimension_struct* var_dimensions = v->dimensions;
     // Calculate lower and upper bounds for each available dimension (up to 3 dims)
@@ -461,7 +451,11 @@ void adios_dimes_write (struct adios_file_struct * fd
         lb[ndims] = adios_get_dim_value (&(var_dimensions->local_offset));
         if (gdims[ndims] > 0 && dims[ndims] > 0)  {
             ub[ndims] = lb[ndims] + dims[ndims] - 1;
+            nelems *= dims[ndims];
             ndims++;
+        } else if (gdims[ndims] > 0 && dims[ndims] == 0) {
+            // piece of array with 0 elements, skip it
+            nelems *= dims[ndims];
         }   else {
             // time dimension (ldim=0 indicates this). Leave out from the dimensions.
             //ub[ndims] = lb[ndims]; 
@@ -485,6 +479,11 @@ void adios_dimes_write (struct adios_file_struct * fd
 
     //snprintf(dspaces_type_var_name, MAX_DS_NAMELEN, "TYPE@%s", ds_var_name);
     
+    /* The next line is just to fix adios_build_index_v1() call not to abort on 
+     * offset=0 variables (in case of files, written variables have offset > 0)
+     */
+    v->write_offset = 1; 
+
     /* non-global variables are put in space ONLY by rank = 0 process */
     if (gdims[0] == 0 && md->rank != 0) {
         //fprintf(stderr, "rank=%d var_name=%s is not global. Skip\n", md->rank, ds_var_name);
@@ -499,7 +498,6 @@ void adios_dimes_write (struct adios_file_struct * fd
     //}
     
      
-    v->write_offset = 1; // only !=0 offsets will be included in build index
     /* This is not needed here, this is already called in common_adios_write() 
     adios_generate_var_characteristics_v1 (fd, v); // characteristics will be included in build index
     adios_write_var_characteristics_v1 (fd, v);
@@ -513,6 +511,13 @@ void adios_dimes_write (struct adios_file_struct * fd
             ds_var_name, adios_type_to_string_int(v->type), v->type, var_type_size, version, ndims,
             dims_str, gdims_str, lb_str, ub_str);    
 
+
+    /* If variable is empty, do not push to space */
+    if (nelems == 0) {
+        log_debug ("rank=%d var_name=%s is empy variable piece. Skip\n", md->rank, ds_var_name);
+        return;
+    }
+
     /* non-timed scalars are written in the metadata at close(), not here */
     if (ndims == 0 && !hastime)
         return;
@@ -984,6 +989,12 @@ void dimes_pack_file_info (int time, int nvars, int nattrs, int group_index_len,
     b[namelen] = 0;
 }
 
+void adios_dimes_buffer_overflow (struct adios_file_struct * fd, 
+                                  struct adios_method_struct * method)
+{
+    // this call never happens without shared buffering
+}
+
 void adios_dimes_close (struct adios_file_struct * fd
                       ,struct adios_method_struct * method
                       )
