@@ -29,6 +29,7 @@
 #include "core/buffer.h"
 #include "core/util.h"
 #include "core/adios_logger.h"
+#include "core/adiost_callback_internal.h"
 
 #if defined ADIOS_TIMERS || defined ADIOS_TIMER_EVENTS
 #include "core/adios_timing.h"
@@ -951,6 +952,16 @@ void * adios_mpi_amr_do_open_thread (void * param)
     return NULL;
 }
 
+/* This is so we can time the worker thread,
+ * and distinguish it from a direct function call. */
+void * adios_mpi_amr_do_open_thread_threaded (void * param)
+{
+    ADIOST_CALLBACK_ENTER(adiost_event_thread, NULL, __func__); 
+    void * rv = adios_mpi_amr_do_open_thread (param);
+    ADIOST_CALLBACK_EXIT(adiost_event_thread, NULL, __func__); 
+    return rv;
+}
+
 // reopen a subfile for append and read/build the existing index
 void * adios_mpi_amr_do_reopen_thread (void * param)
 {
@@ -1065,6 +1076,15 @@ void * adios_mpi_amr_do_write_thread (void * param)
     return NULL;
 }
 
+/* This is so we can time the worker thread,
+ * and distinguish it from a direct function call. */
+void * adios_mpi_amr_do_write_thread_threaded (void * param) {
+    ADIOST_CALLBACK_ENTER(adiost_event_thread, NULL, __func__);
+    void * rv = adios_mpi_amr_do_write_thread (param);
+    ADIOST_CALLBACK_EXIT(adiost_event_thread, NULL, __func__);
+    return rv;
+}
+
 void adios_mpi_amr_init (const PairStruct * parameters
                          ,struct adios_method_struct * method
                          )
@@ -1306,7 +1326,7 @@ int adios_mpi_amr_open (struct adios_file_struct * fd
                 if (md->g_threading)
                 {
                     pthread_create (&md->g_sot, NULL
-                            ,adios_mpi_amr_do_open_thread
+                            ,adios_mpi_amr_do_open_thread_threaded
                             ,(void *) md->open_thread_data
                             );
                 }
@@ -1949,7 +1969,7 @@ void adios_mpi_amr_bg_close (struct adios_file_struct * fd
                 if (md->g_threading)
                 {
                     pthread_create (&md->g_swt, NULL
-                            ,adios_mpi_amr_do_write_thread
+                            ,adios_mpi_amr_do_write_thread_threaded
                             ,(void *) &write_thread_data
                             );
                 }
@@ -2469,7 +2489,7 @@ void adios_mpi_amr_ag_close (struct adios_file_struct * fd
                 if (md->g_threading)
                 {
                     pthread_create (&md->g_swt, NULL
-                            ,adios_mpi_amr_do_write_thread
+                            ,adios_mpi_amr_do_write_thread_threaded
                             ,(void *) &write_thread_data
                             );
                 }
