@@ -117,11 +117,11 @@ int main (int argc, char ** argv)
     alloc_vars();
     adios_read_init_method(ADIOS_READ_METHOD_DATASPACES, subcomm, "verbose=4");
     adios_init_noxml (subcomm);
-    adios_allocate_buffer (ADIOS_BUFFER_ALLOC_NOW, 1);
+    adios_set_max_buffer_size (1);
 
     if (iconnect) 
     {
-        adios_declare_group (&m_adios_group, "connect", "iter", adios_flag_yes);
+        adios_declare_group (&m_adios_group, "connect", "iter", adios_stat_default);
         adios_select_method (m_adios_group, "DATASPACES", "verbose=4", "");
         adios_define_var (m_adios_group, "ldim1", "", adios_integer, 0, 0, 0);
         adios_define_var (m_adios_group, "gdim1", "", adios_integer, 0, 0, 0);
