@@ -283,11 +283,10 @@ int write_index (struct adios_index_struct_v1 * index, char * fname)
     uint64_t index_start = 0; 
     int f;
     uint16_t flag = 0;
-    ssize_t bytes_written = 0;
+
 
     flag |= ADIOS_VERSION_HAVE_SUBFILE;
-    adios_write_index_v1 (&buffer, &buffer_size, &buffer_offset
-            ,index_start, index);
+    adios_write_index_v1 (&buffer, &buffer_size, &buffer_offset, index_start, index);
     if (verbose>2) {
         printf ("buffer=%p size=%" PRId64 " offset=%" PRId64 "\n", buffer, buffer_size, buffer_offset);
     }
@@ -297,7 +296,7 @@ int write_index (struct adios_index_struct_v1 * index, char * fname)
         printf ("buffer=%p size=%" PRId64 " offset=%" PRId64 "\n", buffer, buffer_size, buffer_offset);
     }
 
-    f = open (fname, O_CREAT | O_RDWR, 0644);
+    f = open (fname, O_CREAT | O_WRONLY | O_TRUNC, 0644);
     if (f == -1)
     {
         fprintf (stderr, "Failed to create metadata file %s: %s\n", 
@@ -305,17 +304,56 @@ int write_index (struct adios_index_struct_v1 * index, char * fname)
         return -1;
     }
 
-    bytes_written = write (f, buffer, (size_t)buffer_offset);
-    if (bytes_written == -1) 
+    uint64_t bytes_written = 0;
+    size_t to_write;
+    const size_t MAX_WRITE_SIZE = 0x7ffff000; // = 2,147,479,552
+
+    if (verbose) {
+        printf ("Total size of metadata to write = %" PRIu64 " bytes\n", buffer_offset);
+    }
+
+    while (bytes_written < buffer_offset)
     {
-        fprintf (stderr, "Failed to write metadata to file %s: %s\n", 
-                 fname, strerror(errno));
-    } 
-    else if (bytes_written != (ssize_t) buffer_offset) 
+        if (buffer_offset - bytes_written > MAX_WRITE_SIZE)
+        {
+            to_write = MAX_WRITE_SIZE;
+        }
+        else
+        {
+            to_write = (size_t) (buffer_offset - bytes_written);
+        }
+    
+        if (verbose>2) {
+            printf ("total to write=%" PRIu64 " write now =%ld written so far=%" PRId64 "\n", 
+            buffer_offset, to_write, bytes_written);
+        }
+
+        ssize_t wrote = write (f, buffer+bytes_written, to_write);
+        bytes_written += wrote;
+
+        if (verbose>2) {
+            printf ("wrote=%ld bytes to file\n", wrote);
+        }
+
+        if (wrote == -1)
+        {
+            fprintf (stderr, "Failed to write metadata to file %s: %s\n",
+                     fname, strerror(errno));
+            break;
+        }
+        else if (wrote != to_write)
+        {
+            fprintf (stderr, "Failed to write (a portion of) metadata of %" PRId64 " bytes to file %s. "
+                    "Only wrote %ld bytes\n", buffer_offset, fname, wrote);
+        }
+    }
+
+    if (bytes_written != (ssize_t) buffer_offset)
     {
-        fprintf (stderr, "Failed to write metadata of %" PRId64 " bytes to file %s. "
+        fprintf (stderr, "Failed to write total metadata of %" PRId64 " bytes to file %s. "
                 "Only wrote %lld bytes\n", buffer_offset, fname, (long long)bytes_written);
     }
+
     close(f);
     return 0;
 }
@@ -383,9 +421,13 @@ int process_subfiles (int tid, int startidx, int endidx)
         adios_parse_vars_index_v1 (b[idx], &new_vars_root, NULL, NULL);
         print_variable_index (tid, new_vars_root);
 
-        adios_posix_read_attributes_index (b[idx]);
-        adios_parse_attributes_index_v1 (b[idx], &new_attrs_root);
-        print_attribute_index (tid, new_attrs_root);
+        if (idx == 0)
+        {
+            // only read attributes from the very first file. we don't merge attributes any more
+            adios_posix_read_attributes_index (b[idx]);
+            adios_parse_attributes_index_v1 (b[idx], &new_attrs_root);
+            print_attribute_index (tid, new_attrs_root);
+        }
 
         adios_merge_index_v1 (subindex[tid], new_pg_root, new_vars_root, new_attrs_root, 1); 
 
