@@ -9,7 +9,7 @@ import adios as ad
 import numpy as np
 
 ## Writing
-print "\n>>> Writing ...\n"
+print("\n>>> Writing ...\n")
 
 ad.init("config.xml")
 
@@ -22,7 +22,7 @@ for i in range(10):
     NX = 10
     size = 2
     groupsize =  4 + 4 + 8 * size * NX
-    t = np.array(range(NX*size), dtype=np.float64) + i*NX*size
+    t = np.array(list(range(NX*size)), dtype=np.float64) + i*NX*size
     tt = t.reshape((size, NX))
     ad.set_group_size(fd, groupsize)
     ad.write_int(fd, "NX", NX)
@@ -33,26 +33,25 @@ for i in range(10):
 ad.finalize()
 
 ## Reading
-print "\n>>> Reading step-by-step ...\n"
+print("\n>>> Reading step-by-step ...\n")
 
 f = ad.file("adios_test.bp")
 f.printself()
 
-v = f.var['temperature']
+v = f.vars['temperature']
 v.printself()
 
 for i in range(10):
     val = v.read(from_steps=i, nsteps=1)
-    print "step =", i
-    print val
-    
+    print("step =", i)
+    print(val)
+
 assert ((tt == val).all())
-    
+
 ## Testing
-print "\n>>> Test utility functions ...\n"
+print("\n>>> Test utility functions ...\n")
 
-print "bpls:\n", ad.bpls('adios_test.bp')
-print "readvar:\n", ad.readvar("adios_test.bp", "temperature")
-
-print "\n>>> Done.\n"
+print("bpls:\n", ad.bpls('adios_test.bp'))
+print("readvar:\n", ad.readvar("adios_test.bp", "temperature"))
 
+print("\n>>> Done.\n")
